@@ -1,8 +1,8 @@
-#' @title Minimal Conditional Mutual Information Filter
+#' @title Minimal Conditional Mutual Information Maximization Filter
 #'
 #' @name mlr_filters_cmim
 #'
-#' @description Minimal conditional mutual information maximisation filter
+#' @description Minimal conditional mutual information maximization filter
 #' calling [praznik::CMIM()] from package \CRANpkg{praznik}.
 #'
 #' This filter supports partial scoring (see [Filter]).
@@ -19,10 +19,24 @@
 #' @template seealso_filter
 #' @export
 #' @examples
-#' task = mlr3::tsk("iris")
-#' filter = flt("cmim")
-#' filter$calculate(task, nfeat = 2)
-#' as.data.table(filter)
+#' if (requireNamespace("praznik")) {
+#'   task = mlr3::tsk("iris")
+#'   filter = flt("cmim")
+#'   filter$calculate(task, nfeat = 2)
+#'   as.data.table(filter)
+#' }
+#'
+#' if (mlr3misc::require_namespaces(c("mlr3pipelines", "rpart", "praznik"), quietly = TRUE)) {
+#'   library("mlr3pipelines")
+#'   task = mlr3::tsk("spam")
+#'
+#'   # Note: `filter.frac` is selected randomly and should be tuned.
+#'
+#'   graph = po("filter", filter = flt("cmim"), filter.frac = 0.5) %>>%
+#'     po("learner", mlr3::lrn("classif.rpart"))
+#'
+#'   graph$train(task)
+#' }
 FilterCMIM = R6Class("FilterCMIM",
   inherit = Filter,
 
@@ -41,6 +55,7 @@ FilterCMIM = R6Class("FilterCMIM",
         param_set = param_set,
         feature_types = c("integer", "numeric", "factor", "ordered"),
         packages = "praznik",
+        label = "Minimal Conditional Mutual Information Maximization",
         man = "mlr3filters::mlr_filters_cmim"
       )
     }
