@@ -1,3 +1,4 @@
+
 #' @title Joint Mutual Information Filter
 #'
 #' @name mlr_filters_jmi
@@ -14,16 +15,29 @@
 #'
 #' `r format_bib("bommert_2020")`
 #'
-#'
 #' @template details_praznik
 #' @family Filter
 #' @template seealso_filter
 #' @export
 #' @examples
-#' task = mlr3::tsk("iris")
-#' filter = flt("jmi")
-#' filter$calculate(task, nfeat = 2)
-#' as.data.table(filter)
+#' if (requireNamespace("praznik")) {
+#'   task = mlr3::tsk("iris")
+#'   filter = flt("jmi")
+#'   filter$calculate(task, nfeat = 2)
+#'   as.data.table(filter)
+#' }
+#'
+#' if (mlr3misc::require_namespaces(c("mlr3pipelines", "rpart", "praznik"), quietly = TRUE)) {
+#'   library("mlr3pipelines")
+#'   task = mlr3::tsk("spam")
+#'
+#'   # Note: `filter.frac` is selected randomly and should be tuned.
+#'
+#'   graph = po("filter", filter = flt("jmi"), filter.frac = 0.5) %>>%
+#'     po("learner", mlr3::lrn("classif.rpart"))
+#'
+#'   graph$train(task)
+#' }
 FilterJMI = R6Class("FilterJMI",
   inherit = Filter,
 
@@ -42,6 +56,7 @@ FilterJMI = R6Class("FilterJMI",
         param_set = param_set,
         packages = "praznik",
         feature_types = c("integer", "numeric", "factor", "ordered"),
+        label = "Joint Mutual Information",
         man = "mlr3filters::mlr_filters_jmi"
       )
     }
