@@ -1,4 +1,4 @@
-#' @title Information Gain Filter
+#' @title RELIEF Filter
 #'
 #' @name mlr_filters_relief
 #'
@@ -9,12 +9,26 @@
 #' @template seealso_filter
 #' @export
 #' @examples
-#' ## Relief (default)
-#' task = mlr3::tsk("pima")
-#' filter = flt("relief")
-#' filter$calculate(task)
-#' head(filter$scores, 3)
-#' as.data.table(filter)
+#' if (requireNamespace("FSelectorRcpp")) {
+#'   ## Relief (default)
+#'   task = mlr3::tsk("pima")
+#'   filter = flt("relief")
+#'   filter$calculate(task)
+#'   head(filter$scores, 3)
+#'   as.data.table(filter)
+#' }
+#'
+#' if (mlr3misc::require_namespaces(c("mlr3pipelines", "FSelectorRcpp", "rpart"), quietly = TRUE)) {
+#'   library("mlr3pipelines")
+#'   task = mlr3::tsk("iris")
+#'
+#'   # Note: `filter.frac` is selected randomly and should be tuned.
+#'
+#'   graph = po("filter", filter = flt("relief"), filter.frac = 0.5) %>>%
+#'     po("learner", mlr3::lrn("classif.rpart"))
+#'
+#'   graph$train(task)
+#' }
 FilterRelief = R6Class("FilterRelief",
   inherit = Filter,
 
@@ -33,6 +47,7 @@ FilterRelief = R6Class("FilterRelief",
         param_set = param_set,
         feature_types = c("integer", "numeric", "factor", "ordered"),
         packages = "FSelectorRcpp",
+        label = "RELIEF",
         man = "mlr3filters::mlr_filters_relief"
       )
     }
