@@ -21,6 +21,18 @@
 #' filter$calculate(task)
 #' head(filter$scores, 3)
 #' as.data.table(filter)
+#'
+#' if (mlr3misc::require_namespaces(c("mlr3pipelines", "rpart"), quietly = TRUE)) {
+#'   library("mlr3pipelines")
+#'   task = mlr3::tsk("spam")
+#'
+#'   # Note: `filter.frac` is selected randomly and should be tuned.
+#'
+#'   graph = po("filter", filter = flt("variance"), filter.frac = 0.5) %>>%
+#'     po("learner", mlr3::lrn("classif.rpart"))
+#'
+#'   graph$train(task)
+#' }
 FilterVariance = R6Class("FilterVariance",
   inherit = Filter,
 
@@ -39,6 +51,7 @@ FilterVariance = R6Class("FilterVariance",
         param_set = param_set,
         packages = "stats",
         feature_types = c("integer", "numeric"),
+        label = "Variance",
         man = "mlr3filters::mlr_filters_variance"
       )
     }
